# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class MFAChallengeQuestionLoginInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_preference': 'str',
        'client_id': 'str',
        'client_guid': 'str',
        'issuer_org_id': 'str',
        'issuer_guid': 'str',
        'org_id': 'str',
        'user_id': 'str',
        'user_object': 'UserSummary',
        'login_session': 'LoginSession',
        'upstream_idp': 'str',
        'ip_address': 'str',
        'amr_claim_present': 'bool',
        'last_mfa_login': 'datetime',
        'user_mfa_preferences': 'list[MFAChallengeMethod]'
    }

    attribute_map = {
        'user_preference': 'user_preference',
        'client_id': 'client_id',
        'client_guid': 'client_guid',
        'issuer_org_id': 'issuer_org_id',
        'issuer_guid': 'issuer_guid',
        'org_id': 'org_id',
        'user_id': 'user_id',
        'user_object': 'user_object',
        'login_session': 'login_session',
        'upstream_idp': 'upstream_idp',
        'ip_address': 'ip_address',
        'amr_claim_present': 'amr_claim_present',
        'last_mfa_login': 'last_mfa_login',
        'user_mfa_preferences': 'user_mfa_preferences'
    }

    def __init__(self, user_preference='organisation_policy', client_id=None, client_guid=None, issuer_org_id=None, issuer_guid=None, org_id=None, user_id=None, user_object=None, login_session=None, upstream_idp=None, ip_address=None, amr_claim_present=False, last_mfa_login=None, user_mfa_preferences=None, local_vars_configuration=None):  # noqa: E501
        """MFAChallengeQuestionLoginInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_preference = None
        self._client_id = None
        self._client_guid = None
        self._issuer_org_id = None
        self._issuer_guid = None
        self._org_id = None
        self._user_id = None
        self._user_object = None
        self._login_session = None
        self._upstream_idp = None
        self._ip_address = None
        self._amr_claim_present = None
        self._last_mfa_login = None
        self._user_mfa_preferences = None
        self.discriminator = None

        self.user_preference = user_preference
        self.client_id = client_id
        self.client_guid = client_guid
        self.issuer_org_id = issuer_org_id
        self.issuer_guid = issuer_guid
        self.org_id = org_id
        self.user_id = user_id
        if user_object is not None:
            self.user_object = user_object
        if login_session is not None:
            self.login_session = login_session
        self.upstream_idp = upstream_idp
        self.ip_address = ip_address
        self.amr_claim_present = amr_claim_present
        if last_mfa_login is not None:
            self.last_mfa_login = last_mfa_login
        if user_mfa_preferences is not None:
            self.user_mfa_preferences = user_mfa_preferences

    @property
    def user_preference(self):
        """Gets the user_preference of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The user's preference regarding multi-factor authentication  # noqa: E501

        :return: The user_preference of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_preference

    @user_preference.setter
    def user_preference(self, user_preference):
        """Sets the user_preference of this MFAChallengeQuestionLoginInfo.

        The user's preference regarding multi-factor authentication  # noqa: E501

        :param user_preference: The user_preference of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_preference is None:  # noqa: E501
            raise ValueError("Invalid value for `user_preference`, must not be `None`")  # noqa: E501
        allowed_values = ["always", "organisation_policy"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and user_preference not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `user_preference` ({0}), must be one of {1}"  # noqa: E501
                .format(user_preference, allowed_values)
            )

        self._user_preference = user_preference

    @property
    def client_id(self):
        """Gets the client_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The common name of the client initiating the request on behalf of the user  # noqa: E501

        :return: The client_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this MFAChallengeQuestionLoginInfo.

        The common name of the client initiating the request on behalf of the user  # noqa: E501

        :param client_id: The client_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client_id is not None and len(client_id) > 100):
            raise ValueError("Invalid value for `client_id`, length must be less than or equal to `100`")  # noqa: E501

        self._client_id = client_id

    @property
    def client_guid(self):
        """Gets the client_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The guid of the client initiating the request on behalf of the user  # noqa: E501

        :return: The client_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._client_guid

    @client_guid.setter
    def client_guid(self, client_guid):
        """Sets the client_guid of this MFAChallengeQuestionLoginInfo.

        The guid of the client initiating the request on behalf of the user  # noqa: E501

        :param client_guid: The client_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and client_guid is None:  # noqa: E501
            raise ValueError("Invalid value for `client_guid`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client_guid is not None and len(client_guid) > 40):
            raise ValueError("Invalid value for `client_guid`, length must be less than or equal to `40`")  # noqa: E501

        self._client_guid = client_guid

    @property
    def issuer_org_id(self):
        """Gets the issuer_org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The id of the organisation for the issuer the user is logging in through  # noqa: E501

        :return: The issuer_org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._issuer_org_id

    @issuer_org_id.setter
    def issuer_org_id(self, issuer_org_id):
        """Sets the issuer_org_id of this MFAChallengeQuestionLoginInfo.

        The id of the organisation for the issuer the user is logging in through  # noqa: E501

        :param issuer_org_id: The issuer_org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and issuer_org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `issuer_org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer_org_id is not None and len(issuer_org_id) > 40):
            raise ValueError("Invalid value for `issuer_org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._issuer_org_id = issuer_org_id

    @property
    def issuer_guid(self):
        """Gets the issuer_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The guid of the issuer the user is logging into.  # noqa: E501

        :return: The issuer_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._issuer_guid

    @issuer_guid.setter
    def issuer_guid(self, issuer_guid):
        """Sets the issuer_guid of this MFAChallengeQuestionLoginInfo.

        The guid of the issuer the user is logging into.  # noqa: E501

        :param issuer_guid: The issuer_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and issuer_guid is None:  # noqa: E501
            raise ValueError("Invalid value for `issuer_guid`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer_guid is not None and len(issuer_guid) > 40):
            raise ValueError("Invalid value for `issuer_guid`, length must be less than or equal to `40`")  # noqa: E501

        self._issuer_guid = issuer_guid

    @property
    def org_id(self):
        """Gets the org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The id of the organisation the user is a member of  # noqa: E501

        :return: The org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this MFAChallengeQuestionLoginInfo.

        The id of the organisation the user is a member of  # noqa: E501

        :param org_id: The org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._org_id = org_id

    @property
    def user_id(self):
        """Gets the user_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The id of the user requesting access  # noqa: E501

        :return: The user_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this MFAChallengeQuestionLoginInfo.

        The id of the user requesting access  # noqa: E501

        :param user_id: The user_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_id is not None and len(user_id) > 40):
            raise ValueError("Invalid value for `user_id`, length must be less than or equal to `40`")  # noqa: E501

        self._user_id = user_id

    @property
    def user_object(self):
        """Gets the user_object of this MFAChallengeQuestionLoginInfo.  # noqa: E501


        :return: The user_object of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: UserSummary
        """
        return self._user_object

    @user_object.setter
    def user_object(self, user_object):
        """Sets the user_object of this MFAChallengeQuestionLoginInfo.


        :param user_object: The user_object of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: UserSummary
        """

        self._user_object = user_object

    @property
    def login_session(self):
        """Gets the login_session of this MFAChallengeQuestionLoginInfo.  # noqa: E501


        :return: The login_session of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: LoginSession
        """
        return self._login_session

    @login_session.setter
    def login_session(self, login_session):
        """Sets the login_session of this MFAChallengeQuestionLoginInfo.


        :param login_session: The login_session of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: LoginSession
        """

        self._login_session = login_session

    @property
    def upstream_idp(self):
        """Gets the upstream_idp of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The upstream IDP that the user is authenticating against  # noqa: E501

        :return: The upstream_idp of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._upstream_idp

    @upstream_idp.setter
    def upstream_idp(self, upstream_idp):
        """Sets the upstream_idp of this MFAChallengeQuestionLoginInfo.

        The upstream IDP that the user is authenticating against  # noqa: E501

        :param upstream_idp: The upstream_idp of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and upstream_idp is None:  # noqa: E501
            raise ValueError("Invalid value for `upstream_idp`, must not be `None`")  # noqa: E501

        self._upstream_idp = upstream_idp

    @property
    def ip_address(self):
        """Gets the ip_address of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The source ip address of the user's request. Both IPv4 and IPv6 address are supported  # noqa: E501

        :return: The ip_address of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this MFAChallengeQuestionLoginInfo.

        The source ip address of the user's request. Both IPv4 and IPv6 address are supported  # noqa: E501

        :param ip_address: The ip_address of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ip_address is None:  # noqa: E501
            raise ValueError("Invalid value for `ip_address`, must not be `None`")  # noqa: E501

        self._ip_address = ip_address

    @property
    def amr_claim_present(self):
        """Gets the amr_claim_present of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        Whether the amr claim is present in the response from the upstream  # noqa: E501

        :return: The amr_claim_present of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: bool
        """
        return self._amr_claim_present

    @amr_claim_present.setter
    def amr_claim_present(self, amr_claim_present):
        """Sets the amr_claim_present of this MFAChallengeQuestionLoginInfo.

        Whether the amr claim is present in the response from the upstream  # noqa: E501

        :param amr_claim_present: The amr_claim_present of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and amr_claim_present is None:  # noqa: E501
            raise ValueError("Invalid value for `amr_claim_present`, must not be `None`")  # noqa: E501

        self._amr_claim_present = amr_claim_present

    @property
    def last_mfa_login(self):
        """Gets the last_mfa_login of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The time of the user's last successful multi-factor authenticated login  # noqa: E501

        :return: The last_mfa_login of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._last_mfa_login

    @last_mfa_login.setter
    def last_mfa_login(self, last_mfa_login):
        """Sets the last_mfa_login of this MFAChallengeQuestionLoginInfo.

        The time of the user's last successful multi-factor authenticated login  # noqa: E501

        :param last_mfa_login: The last_mfa_login of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: datetime
        """

        self._last_mfa_login = last_mfa_login

    @property
    def user_mfa_preferences(self):
        """Gets the user_mfa_preferences of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The list of a user's multi-factor challenge methods  # noqa: E501

        :return: The user_mfa_preferences of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: list[MFAChallengeMethod]
        """
        return self._user_mfa_preferences

    @user_mfa_preferences.setter
    def user_mfa_preferences(self, user_mfa_preferences):
        """Sets the user_mfa_preferences of this MFAChallengeQuestionLoginInfo.

        The list of a user's multi-factor challenge methods  # noqa: E501

        :param user_mfa_preferences: The user_mfa_preferences of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: list[MFAChallengeMethod]
        """

        self._user_mfa_preferences = user_mfa_preferences

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MFAChallengeQuestionLoginInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MFAChallengeQuestionLoginInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class WebAuthNEnrollmentAnswer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'credential_id': 'str',
        'client_data': 'str',
        'authenticator_data': 'str',
        'signature': 'str',
        'user_handle': 'str',
        'transports': 'list[str]'
    }

    attribute_map = {
        'user_id': 'user_id',
        'credential_id': 'credential_id',
        'client_data': 'client_data',
        'authenticator_data': 'authenticator_data',
        'signature': 'signature',
        'user_handle': 'user_handle',
        'transports': 'transports'
    }

    def __init__(self, user_id=None, credential_id=None, client_data=None, authenticator_data=None, signature=None, user_handle=None, transports=None, local_vars_configuration=None):  # noqa: E501
        """WebAuthNEnrollmentAnswer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._credential_id = None
        self._client_data = None
        self._authenticator_data = None
        self._signature = None
        self._user_handle = None
        self._transports = None
        self.discriminator = None

        self.user_id = user_id
        self.credential_id = credential_id
        self.client_data = client_data
        if authenticator_data is not None:
            self.authenticator_data = authenticator_data
        if signature is not None:
            self.signature = signature
        if user_handle is not None:
            self.user_handle = user_handle
        if transports is not None:
            self.transports = transports

    @property
    def user_id(self):
        """Gets the user_id of this WebAuthNEnrollmentAnswer.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The user_id of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this WebAuthNEnrollmentAnswer.

        Unique identifier  # noqa: E501

        :param user_id: The user_id of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def credential_id(self):
        """Gets the credential_id of this WebAuthNEnrollmentAnswer.  # noqa: E501

        A base64 encoding of the credential ID choosen by the authenticator  # noqa: E501

        :return: The credential_id of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :rtype: str
        """
        return self._credential_id

    @credential_id.setter
    def credential_id(self, credential_id):
        """Sets the credential_id of this WebAuthNEnrollmentAnswer.

        A base64 encoding of the credential ID choosen by the authenticator  # noqa: E501

        :param credential_id: The credential_id of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and credential_id is None:  # noqa: E501
            raise ValueError("Invalid value for `credential_id`, must not be `None`")  # noqa: E501

        self._credential_id = credential_id

    @property
    def client_data(self):
        """Gets the client_data of this WebAuthNEnrollmentAnswer.  # noqa: E501

        JSON encoded collection of key-value mappings representing the contextual bindings of the relying party and client  # noqa: E501

        :return: The client_data of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :rtype: str
        """
        return self._client_data

    @client_data.setter
    def client_data(self, client_data):
        """Sets the client_data of this WebAuthNEnrollmentAnswer.

        JSON encoded collection of key-value mappings representing the contextual bindings of the relying party and client  # noqa: E501

        :param client_data: The client_data of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and client_data is None:  # noqa: E501
            raise ValueError("Invalid value for `client_data`, must not be `None`")  # noqa: E501

        self._client_data = client_data

    @property
    def authenticator_data(self):
        """Gets the authenticator_data of this WebAuthNEnrollmentAnswer.  # noqa: E501

        Opaque string representing the authentication data, and attestion statements.  # noqa: E501

        :return: The authenticator_data of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :rtype: str
        """
        return self._authenticator_data

    @authenticator_data.setter
    def authenticator_data(self, authenticator_data):
        """Sets the authenticator_data of this WebAuthNEnrollmentAnswer.

        Opaque string representing the authentication data, and attestion statements.  # noqa: E501

        :param authenticator_data: The authenticator_data of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :type: str
        """

        self._authenticator_data = authenticator_data

    @property
    def signature(self):
        """Gets the signature of this WebAuthNEnrollmentAnswer.  # noqa: E501

        The raw signature from the authenticator. This value is only included in the Authentication Assertion Response. For details see https://developer.mozilla.org/en-US/docs/Web/API/AuthenticatorAssertionResponse  # noqa: E501

        :return: The signature of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this WebAuthNEnrollmentAnswer.

        The raw signature from the authenticator. This value is only included in the Authentication Assertion Response. For details see https://developer.mozilla.org/en-US/docs/Web/API/AuthenticatorAssertionResponse  # noqa: E501

        :param signature: The signature of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :type: str
        """

        self._signature = signature

    @property
    def user_handle(self):
        """Gets the user_handle of this WebAuthNEnrollmentAnswer.  # noqa: E501

        The user handle returned from the authenticator. This is optionally included in the Authentication Assertion Response.  # noqa: E501

        :return: The user_handle of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :rtype: str
        """
        return self._user_handle

    @user_handle.setter
    def user_handle(self, user_handle):
        """Sets the user_handle of this WebAuthNEnrollmentAnswer.

        The user handle returned from the authenticator. This is optionally included in the Authentication Assertion Response.  # noqa: E501

        :param user_handle: The user_handle of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :type: str
        """

        self._user_handle = user_handle

    @property
    def transports(self):
        """Gets the transports of this WebAuthNEnrollmentAnswer.  # noqa: E501

        List of supported transports for this enrolled credential  # noqa: E501

        :return: The transports of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :rtype: list[str]
        """
        return self._transports

    @transports.setter
    def transports(self, transports):
        """Sets the transports of this WebAuthNEnrollmentAnswer.

        List of supported transports for this enrolled credential  # noqa: E501

        :param transports: The transports of this WebAuthNEnrollmentAnswer.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["internal", "ble", "nfc", "usb"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(transports).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `transports` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(transports) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._transports = transports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebAuthNEnrollmentAnswer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebAuthNEnrollmentAnswer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class SessionsSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'org_id': 'str',
        'revoked': 'bool',
        'number_of_logins': 'int',
        'number_of_failed_multi_factor_challenges': 'int'
    }

    attribute_map = {
        'user_id': 'user_id',
        'org_id': 'org_id',
        'revoked': 'revoked',
        'number_of_logins': 'number_of_logins',
        'number_of_failed_multi_factor_challenges': 'number_of_failed_multi_factor_challenges'
    }

    def __init__(self, user_id=None, org_id=None, revoked=None, number_of_logins=None, number_of_failed_multi_factor_challenges=None, local_vars_configuration=None):  # noqa: E501
        """SessionsSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._org_id = None
        self._revoked = None
        self._number_of_logins = None
        self._number_of_failed_multi_factor_challenges = None
        self.discriminator = None

        self.user_id = user_id
        self.org_id = org_id
        if revoked is not None:
            self.revoked = revoked
        if number_of_logins is not None:
            self.number_of_logins = number_of_logins
        if number_of_failed_multi_factor_challenges is not None:
            self.number_of_failed_multi_factor_challenges = number_of_failed_multi_factor_challenges

    @property
    def user_id(self):
        """Gets the user_id of this SessionsSpec.  # noqa: E501

        The user id associated with the session  # noqa: E501

        :return: The user_id of this SessionsSpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SessionsSpec.

        The user id associated with the session  # noqa: E501

        :param user_id: The user_id of this SessionsSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def org_id(self):
        """Gets the org_id of this SessionsSpec.  # noqa: E501

        The org id associated with the issuer the user is logging into  # noqa: E501

        :return: The org_id of this SessionsSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this SessionsSpec.

        The org id associated with the issuer the user is logging into  # noqa: E501

        :param org_id: The org_id of this SessionsSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def revoked(self):
        """Gets the revoked of this SessionsSpec.  # noqa: E501

        The status of a the session. A session is no longer valid if it has been revoked.  # noqa: E501

        :return: The revoked of this SessionsSpec.  # noqa: E501
        :rtype: bool
        """
        return self._revoked

    @revoked.setter
    def revoked(self, revoked):
        """Sets the revoked of this SessionsSpec.

        The status of a the session. A session is no longer valid if it has been revoked.  # noqa: E501

        :param revoked: The revoked of this SessionsSpec.  # noqa: E501
        :type: bool
        """

        self._revoked = revoked

    @property
    def number_of_logins(self):
        """Gets the number_of_logins of this SessionsSpec.  # noqa: E501

        The number of times a user has logged in during this session  # noqa: E501

        :return: The number_of_logins of this SessionsSpec.  # noqa: E501
        :rtype: int
        """
        return self._number_of_logins

    @number_of_logins.setter
    def number_of_logins(self, number_of_logins):
        """Sets the number_of_logins of this SessionsSpec.

        The number of times a user has logged in during this session  # noqa: E501

        :param number_of_logins: The number_of_logins of this SessionsSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number_of_logins is not None and number_of_logins < 0):  # noqa: E501
            raise ValueError("Invalid value for `number_of_logins`, must be a value greater than or equal to `0`")  # noqa: E501

        self._number_of_logins = number_of_logins

    @property
    def number_of_failed_multi_factor_challenges(self):
        """Gets the number_of_failed_multi_factor_challenges of this SessionsSpec.  # noqa: E501

        The number of times a user has failed a multi-factor authentication challenge associated with this session  # noqa: E501

        :return: The number_of_failed_multi_factor_challenges of this SessionsSpec.  # noqa: E501
        :rtype: int
        """
        return self._number_of_failed_multi_factor_challenges

    @number_of_failed_multi_factor_challenges.setter
    def number_of_failed_multi_factor_challenges(self, number_of_failed_multi_factor_challenges):
        """Sets the number_of_failed_multi_factor_challenges of this SessionsSpec.

        The number of times a user has failed a multi-factor authentication challenge associated with this session  # noqa: E501

        :param number_of_failed_multi_factor_challenges: The number_of_failed_multi_factor_challenges of this SessionsSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number_of_failed_multi_factor_challenges is not None and number_of_failed_multi_factor_challenges < 0):  # noqa: E501
            raise ValueError("Invalid value for `number_of_failed_multi_factor_challenges`, must be a value greater than or equal to `0`")  # noqa: E501

        self._number_of_failed_multi_factor_challenges = number_of_failed_multi_factor_challenges

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionsSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SessionsSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorAuthzStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allowed': 'int',
        'allowed_app_handled': 'int',
        'denied': 'int',
        'token_cached_failed': 'int',
        'token_cached_success': 'int',
        'token_parse_failed': 'int',
        'token_static_token': 'int',
        'token_bad_jti': 'int',
        'token_lookup_success': 'int',
        'token_lookup_notfound': 'int',
        'token_lookup_badrequest': 'int',
        'token_lookup_4xx_other': 'int',
        'token_lookup_error': 'int',
        'token_lookup_revoked': 'int',
        'token_basic_auth_decode_fail': 'int',
        'token_basic_auth_too_long': 'int',
        'token_basic_auth_no_password': 'int',
        'token_basic_auth_cached_success': 'int',
        'token_basic_auth_cached_failed': 'int'
    }

    attribute_map = {
        'allowed': 'allowed',
        'allowed_app_handled': 'allowed_app_handled',
        'denied': 'denied',
        'token_cached_failed': 'token_cached_failed',
        'token_cached_success': 'token_cached_success',
        'token_parse_failed': 'token_parse_failed',
        'token_static_token': 'token_static_token',
        'token_bad_jti': 'token_bad_jti',
        'token_lookup_success': 'token_lookup_success',
        'token_lookup_notfound': 'token_lookup_notfound',
        'token_lookup_badrequest': 'token_lookup_badrequest',
        'token_lookup_4xx_other': 'token_lookup_4xx_other',
        'token_lookup_error': 'token_lookup_error',
        'token_lookup_revoked': 'token_lookup_revoked',
        'token_basic_auth_decode_fail': 'token_basic_auth_decode_fail',
        'token_basic_auth_too_long': 'token_basic_auth_too_long',
        'token_basic_auth_no_password': 'token_basic_auth_no_password',
        'token_basic_auth_cached_success': 'token_basic_auth_cached_success',
        'token_basic_auth_cached_failed': 'token_basic_auth_cached_failed'
    }

    def __init__(self, allowed=None, allowed_app_handled=None, denied=None, token_cached_failed=None, token_cached_success=None, token_parse_failed=None, token_static_token=None, token_bad_jti=None, token_lookup_success=None, token_lookup_notfound=None, token_lookup_badrequest=None, token_lookup_4xx_other=None, token_lookup_error=None, token_lookup_revoked=None, token_basic_auth_decode_fail=None, token_basic_auth_too_long=None, token_basic_auth_no_password=None, token_basic_auth_cached_success=None, token_basic_auth_cached_failed=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorAuthzStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allowed = None
        self._allowed_app_handled = None
        self._denied = None
        self._token_cached_failed = None
        self._token_cached_success = None
        self._token_parse_failed = None
        self._token_static_token = None
        self._token_bad_jti = None
        self._token_lookup_success = None
        self._token_lookup_notfound = None
        self._token_lookup_badrequest = None
        self._token_lookup_4xx_other = None
        self._token_lookup_error = None
        self._token_lookup_revoked = None
        self._token_basic_auth_decode_fail = None
        self._token_basic_auth_too_long = None
        self._token_basic_auth_no_password = None
        self._token_basic_auth_cached_success = None
        self._token_basic_auth_cached_failed = None
        self.discriminator = None

        self.allowed = allowed
        self.allowed_app_handled = allowed_app_handled
        self.denied = denied
        self.token_cached_failed = token_cached_failed
        self.token_cached_success = token_cached_success
        self.token_parse_failed = token_parse_failed
        self.token_static_token = token_static_token
        self.token_bad_jti = token_bad_jti
        self.token_lookup_success = token_lookup_success
        self.token_lookup_notfound = token_lookup_notfound
        self.token_lookup_badrequest = token_lookup_badrequest
        self.token_lookup_4xx_other = token_lookup_4xx_other
        self.token_lookup_error = token_lookup_error
        self.token_lookup_revoked = token_lookup_revoked
        self.token_basic_auth_decode_fail = token_basic_auth_decode_fail
        self.token_basic_auth_too_long = token_basic_auth_too_long
        self.token_basic_auth_no_password = token_basic_auth_no_password
        self.token_basic_auth_cached_success = token_basic_auth_cached_success
        self.token_basic_auth_cached_failed = token_basic_auth_cached_failed

    @property
    def allowed(self):
        """Gets the allowed of this AgentConnectorAuthzStats.  # noqa: E501

        The number of allowed requests.   # noqa: E501

        :return: The allowed of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._allowed

    @allowed.setter
    def allowed(self, allowed):
        """Sets the allowed of this AgentConnectorAuthzStats.

        The number of allowed requests.   # noqa: E501

        :param allowed: The allowed of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and allowed is None:  # noqa: E501
            raise ValueError("Invalid value for `allowed`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                allowed is not None and allowed < 0):  # noqa: E501
            raise ValueError("Invalid value for `allowed`, must be a value greater than or equal to `0`")  # noqa: E501

        self._allowed = allowed

    @property
    def allowed_app_handled(self):
        """Gets the allowed_app_handled of this AgentConnectorAuthzStats.  # noqa: E501

        The authz has been allowed due to the authentication handled by the application.   # noqa: E501

        :return: The allowed_app_handled of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._allowed_app_handled

    @allowed_app_handled.setter
    def allowed_app_handled(self, allowed_app_handled):
        """Sets the allowed_app_handled of this AgentConnectorAuthzStats.

        The authz has been allowed due to the authentication handled by the application.   # noqa: E501

        :param allowed_app_handled: The allowed_app_handled of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and allowed_app_handled is None:  # noqa: E501
            raise ValueError("Invalid value for `allowed_app_handled`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                allowed_app_handled is not None and allowed_app_handled < 0):  # noqa: E501
            raise ValueError("Invalid value for `allowed_app_handled`, must be a value greater than or equal to `0`")  # noqa: E501

        self._allowed_app_handled = allowed_app_handled

    @property
    def denied(self):
        """Gets the denied of this AgentConnectorAuthzStats.  # noqa: E501

        The number of denied requests.   # noqa: E501

        :return: The denied of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._denied

    @denied.setter
    def denied(self, denied):
        """Sets the denied of this AgentConnectorAuthzStats.

        The number of denied requests.   # noqa: E501

        :param denied: The denied of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and denied is None:  # noqa: E501
            raise ValueError("Invalid value for `denied`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                denied is not None and denied < 0):  # noqa: E501
            raise ValueError("Invalid value for `denied`, must be a value greater than or equal to `0`")  # noqa: E501

        self._denied = denied

    @property
    def token_cached_failed(self):
        """Gets the token_cached_failed of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a failed lookup response was returned that had been cached.   # noqa: E501

        :return: The token_cached_failed of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_cached_failed

    @token_cached_failed.setter
    def token_cached_failed(self, token_cached_failed):
        """Sets the token_cached_failed of this AgentConnectorAuthzStats.

        The number of times a failed lookup response was returned that had been cached.   # noqa: E501

        :param token_cached_failed: The token_cached_failed of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_cached_failed is None:  # noqa: E501
            raise ValueError("Invalid value for `token_cached_failed`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_cached_failed is not None and token_cached_failed < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_cached_failed`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_cached_failed = token_cached_failed

    @property
    def token_cached_success(self):
        """Gets the token_cached_success of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a successful lookup response was returned that had been cached.   # noqa: E501

        :return: The token_cached_success of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_cached_success

    @token_cached_success.setter
    def token_cached_success(self, token_cached_success):
        """Sets the token_cached_success of this AgentConnectorAuthzStats.

        The number of times a successful lookup response was returned that had been cached.   # noqa: E501

        :param token_cached_success: The token_cached_success of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_cached_success is None:  # noqa: E501
            raise ValueError("Invalid value for `token_cached_success`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_cached_success is not None and token_cached_success < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_cached_success`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_cached_success = token_cached_success

    @property
    def token_parse_failed(self):
        """Gets the token_parse_failed of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a there was a failure parsing the token. This is due to missing claims in the token.   # noqa: E501

        :return: The token_parse_failed of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_parse_failed

    @token_parse_failed.setter
    def token_parse_failed(self, token_parse_failed):
        """Sets the token_parse_failed of this AgentConnectorAuthzStats.

        The number of times a there was a failure parsing the token. This is due to missing claims in the token.   # noqa: E501

        :param token_parse_failed: The token_parse_failed of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_parse_failed is None:  # noqa: E501
            raise ValueError("Invalid value for `token_parse_failed`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_parse_failed is not None and token_parse_failed < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_parse_failed`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_parse_failed = token_parse_failed

    @property
    def token_static_token(self):
        """Gets the token_static_token of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a static token was used in a request.   # noqa: E501

        :return: The token_static_token of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_static_token

    @token_static_token.setter
    def token_static_token(self, token_static_token):
        """Sets the token_static_token of this AgentConnectorAuthzStats.

        The number of times a static token was used in a request.   # noqa: E501

        :param token_static_token: The token_static_token of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_static_token is None:  # noqa: E501
            raise ValueError("Invalid value for `token_static_token`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_static_token is not None and token_static_token < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_static_token`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_static_token = token_static_token

    @property
    def token_bad_jti(self):
        """Gets the token_bad_jti of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times the token JTI was missing.   # noqa: E501

        :return: The token_bad_jti of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_bad_jti

    @token_bad_jti.setter
    def token_bad_jti(self, token_bad_jti):
        """Sets the token_bad_jti of this AgentConnectorAuthzStats.

        The number of times the token JTI was missing.   # noqa: E501

        :param token_bad_jti: The token_bad_jti of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_bad_jti is None:  # noqa: E501
            raise ValueError("Invalid value for `token_bad_jti`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_bad_jti is not None and token_bad_jti < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_bad_jti`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_bad_jti = token_bad_jti

    @property
    def token_lookup_success(self):
        """Gets the token_lookup_success of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a token introspect was performed and the result was success.   # noqa: E501

        :return: The token_lookup_success of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_lookup_success

    @token_lookup_success.setter
    def token_lookup_success(self, token_lookup_success):
        """Sets the token_lookup_success of this AgentConnectorAuthzStats.

        The number of times a token introspect was performed and the result was success.   # noqa: E501

        :param token_lookup_success: The token_lookup_success of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_lookup_success is None:  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_success`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_lookup_success is not None and token_lookup_success < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_success`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_lookup_success = token_lookup_success

    @property
    def token_lookup_notfound(self):
        """Gets the token_lookup_notfound of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a token introspect was performed and the result was not found.   # noqa: E501

        :return: The token_lookup_notfound of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_lookup_notfound

    @token_lookup_notfound.setter
    def token_lookup_notfound(self, token_lookup_notfound):
        """Sets the token_lookup_notfound of this AgentConnectorAuthzStats.

        The number of times a token introspect was performed and the result was not found.   # noqa: E501

        :param token_lookup_notfound: The token_lookup_notfound of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_lookup_notfound is None:  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_notfound`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_lookup_notfound is not None and token_lookup_notfound < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_notfound`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_lookup_notfound = token_lookup_notfound

    @property
    def token_lookup_badrequest(self):
        """Gets the token_lookup_badrequest of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a token introspect was performed and the result was a bad request   # noqa: E501

        :return: The token_lookup_badrequest of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_lookup_badrequest

    @token_lookup_badrequest.setter
    def token_lookup_badrequest(self, token_lookup_badrequest):
        """Sets the token_lookup_badrequest of this AgentConnectorAuthzStats.

        The number of times a token introspect was performed and the result was a bad request   # noqa: E501

        :param token_lookup_badrequest: The token_lookup_badrequest of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_lookup_badrequest is None:  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_badrequest`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_lookup_badrequest is not None and token_lookup_badrequest < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_badrequest`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_lookup_badrequest = token_lookup_badrequest

    @property
    def token_lookup_4xx_other(self):
        """Gets the token_lookup_4xx_other of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a token introspect was performed and the result was a 4xx result that was not a 404, 410 or 400.   # noqa: E501

        :return: The token_lookup_4xx_other of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_lookup_4xx_other

    @token_lookup_4xx_other.setter
    def token_lookup_4xx_other(self, token_lookup_4xx_other):
        """Sets the token_lookup_4xx_other of this AgentConnectorAuthzStats.

        The number of times a token introspect was performed and the result was a 4xx result that was not a 404, 410 or 400.   # noqa: E501

        :param token_lookup_4xx_other: The token_lookup_4xx_other of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_lookup_4xx_other is None:  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_4xx_other`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_lookup_4xx_other is not None and token_lookup_4xx_other < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_4xx_other`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_lookup_4xx_other = token_lookup_4xx_other

    @property
    def token_lookup_error(self):
        """Gets the token_lookup_error of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a token introspect was performed and the result was an error.   # noqa: E501

        :return: The token_lookup_error of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_lookup_error

    @token_lookup_error.setter
    def token_lookup_error(self, token_lookup_error):
        """Sets the token_lookup_error of this AgentConnectorAuthzStats.

        The number of times a token introspect was performed and the result was an error.   # noqa: E501

        :param token_lookup_error: The token_lookup_error of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_lookup_error is None:  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_error`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_lookup_error is not None and token_lookup_error < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_error`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_lookup_error = token_lookup_error

    @property
    def token_lookup_revoked(self):
        """Gets the token_lookup_revoked of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a token introspect was performed and the result returned was that the token has been revoked.   # noqa: E501

        :return: The token_lookup_revoked of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_lookup_revoked

    @token_lookup_revoked.setter
    def token_lookup_revoked(self, token_lookup_revoked):
        """Sets the token_lookup_revoked of this AgentConnectorAuthzStats.

        The number of times a token introspect was performed and the result returned was that the token has been revoked.   # noqa: E501

        :param token_lookup_revoked: The token_lookup_revoked of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_lookup_revoked is None:  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_revoked`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_lookup_revoked is not None and token_lookup_revoked < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_lookup_revoked`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_lookup_revoked = token_lookup_revoked

    @property
    def token_basic_auth_decode_fail(self):
        """Gets the token_basic_auth_decode_fail of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a request was made with basic auth and the base64 decode failed.   # noqa: E501

        :return: The token_basic_auth_decode_fail of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_basic_auth_decode_fail

    @token_basic_auth_decode_fail.setter
    def token_basic_auth_decode_fail(self, token_basic_auth_decode_fail):
        """Sets the token_basic_auth_decode_fail of this AgentConnectorAuthzStats.

        The number of times a request was made with basic auth and the base64 decode failed.   # noqa: E501

        :param token_basic_auth_decode_fail: The token_basic_auth_decode_fail of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_basic_auth_decode_fail is None:  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_decode_fail`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_basic_auth_decode_fail is not None and token_basic_auth_decode_fail < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_decode_fail`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_basic_auth_decode_fail = token_basic_auth_decode_fail

    @property
    def token_basic_auth_too_long(self):
        """Gets the token_basic_auth_too_long of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a request was made with basic auth and the basic auth string was too long. The maximum size permitted is 141 characters.   # noqa: E501

        :return: The token_basic_auth_too_long of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_basic_auth_too_long

    @token_basic_auth_too_long.setter
    def token_basic_auth_too_long(self, token_basic_auth_too_long):
        """Sets the token_basic_auth_too_long of this AgentConnectorAuthzStats.

        The number of times a request was made with basic auth and the basic auth string was too long. The maximum size permitted is 141 characters.   # noqa: E501

        :param token_basic_auth_too_long: The token_basic_auth_too_long of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_basic_auth_too_long is None:  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_too_long`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_basic_auth_too_long is not None and token_basic_auth_too_long < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_too_long`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_basic_auth_too_long = token_basic_auth_too_long

    @property
    def token_basic_auth_no_password(self):
        """Gets the token_basic_auth_no_password of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a request was made with basic auth and the password was missing.   # noqa: E501

        :return: The token_basic_auth_no_password of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_basic_auth_no_password

    @token_basic_auth_no_password.setter
    def token_basic_auth_no_password(self, token_basic_auth_no_password):
        """Sets the token_basic_auth_no_password of this AgentConnectorAuthzStats.

        The number of times a request was made with basic auth and the password was missing.   # noqa: E501

        :param token_basic_auth_no_password: The token_basic_auth_no_password of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_basic_auth_no_password is None:  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_no_password`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_basic_auth_no_password is not None and token_basic_auth_no_password < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_no_password`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_basic_auth_no_password = token_basic_auth_no_password

    @property
    def token_basic_auth_cached_success(self):
        """Gets the token_basic_auth_cached_success of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a request was made with basic auth and the successful result was returned from the cache.   # noqa: E501

        :return: The token_basic_auth_cached_success of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_basic_auth_cached_success

    @token_basic_auth_cached_success.setter
    def token_basic_auth_cached_success(self, token_basic_auth_cached_success):
        """Sets the token_basic_auth_cached_success of this AgentConnectorAuthzStats.

        The number of times a request was made with basic auth and the successful result was returned from the cache.   # noqa: E501

        :param token_basic_auth_cached_success: The token_basic_auth_cached_success of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_basic_auth_cached_success is None:  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_cached_success`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_basic_auth_cached_success is not None and token_basic_auth_cached_success < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_cached_success`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_basic_auth_cached_success = token_basic_auth_cached_success

    @property
    def token_basic_auth_cached_failed(self):
        """Gets the token_basic_auth_cached_failed of this AgentConnectorAuthzStats.  # noqa: E501

        The number of times a request was made with basic auth and the failed result was returned from the cache.   # noqa: E501

        :return: The token_basic_auth_cached_failed of this AgentConnectorAuthzStats.  # noqa: E501
        :rtype: int
        """
        return self._token_basic_auth_cached_failed

    @token_basic_auth_cached_failed.setter
    def token_basic_auth_cached_failed(self, token_basic_auth_cached_failed):
        """Sets the token_basic_auth_cached_failed of this AgentConnectorAuthzStats.

        The number of times a request was made with basic auth and the failed result was returned from the cache.   # noqa: E501

        :param token_basic_auth_cached_failed: The token_basic_auth_cached_failed of this AgentConnectorAuthzStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and token_basic_auth_cached_failed is None:  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_cached_failed`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                token_basic_auth_cached_failed is not None and token_basic_auth_cached_failed < 0):  # noqa: E501
            raise ValueError("Invalid value for `token_basic_auth_cached_failed`, must be a value greater than or equal to `0`")  # noqa: E501

        self._token_basic_auth_cached_failed = token_basic_auth_cached_failed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorAuthzStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorAuthzStats):
            return True

        return self.to_dict() != other.to_dict()
